InterruptIdentification

Struct InterruptIdentification 

pub struct InterruptIdentification { /* private fields */ }
Interrupt Identification Register

Implementations

Source

impl InterruptIdentification

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> InterruptIdentification

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn fifo_enabled(&self) -> u2

16550 mode enabled?

pub const fn int_id(&self) -> Result<InterruptId2, u3>

Interrupt ID2.

pub const fn int_pend_n(&self) -> bool

Interrupt Pending, active low.