ClockConfig

Struct ClockConfig 

pub struct ClockConfig {
    pub div: u16,
}
Clock configuration structure.

Fields

div: u16

Divisor value.

Implementations

Source

impl ClockConfig

pub fn new(div: u16) -> Self

New clock config with the given divisor.

pub fn div_msb(&self) -> u8

MSB part of the divisor.

pub fn div_lsb(&self) -> u8

LSB part of the divisor.

pub fn new_autocalc_with_error( clk_in: HertzU32, baudrate: u32, ) -> Result<(Self, f32), ClockConfigError>

This function calculates the required divisor values for a given input clock and baudrate as well as an baud error rate.

pub fn new_autocalc( clk_in: HertzU32, baudrate: u32, ) -> Result<Self, ClockConfigError>

This function calculates the required divisor values for a given input clock and baudrate.

The function will not calculate the error rate. You can use Self::calculate_error_rate to check the error rate, or use the Self::new_autocalc_with_error function to get both the clock config and its baud error.

pub fn calculate_error_rate( &self, clk_in: HertzU32, baudrate: u32, ) -> Result<f32, DivisorZeroError>

Calculate the error rate of the baudrate with the given clock frequency, baudrate and the current clock config as a floating point value between 0.0 and 1.0.

pub const fn calc_div_with_integer_div( clk_in: HertzU32, baudrate: u32, ) -> Result<u32, DivisorZeroError>

Calculate the divisor from an input clock for a give target baudrate.