pub struct InterruptIdentification { /* private fields */ }Expand description
Interrupt Identification Register
Implementations
Sourceimpl InterruptIdentification
impl InterruptIdentification
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> InterruptIdentification
pub const fn new_with_raw_value(value: u32) -> InterruptIdentification
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn fifo_enabled(&self) -> u2
pub const fn fifo_enabled(&self) -> u2
16550 mode enabled?
Sourcepub const fn int_id(&self) -> Result<InterruptId2, u3>
pub const fn int_id(&self) -> Result<InterruptId2, u3>
Interrupt ID2.
Sourcepub const fn int_pend_n(&self) -> bool
pub const fn int_pend_n(&self) -> bool
Interrupt Pending, active low.