pub struct LineStatus { /* private fields */ }Expand description
Line Status Register
Implementations
Sourceimpl LineStatus
impl LineStatus
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> LineStatus
pub const fn new_with_raw_value(value: u32) -> LineStatus
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn error_in_rx_fifo(&self) -> bool
pub const fn error_in_rx_fifo(&self) -> bool
Error in RX FIFO.
Sourcepub const fn with_error_in_rx_fifo(&self, field_value: bool) -> Self
pub const fn with_error_in_rx_fifo(&self, field_value: bool) -> Self
Error in RX FIFO.
Sourcepub fn set_error_in_rx_fifo(&mut self, field_value: bool)
pub fn set_error_in_rx_fifo(&mut self, field_value: bool)
Error in RX FIFO.
Sourcepub const fn tx_empty(&self) -> bool
pub const fn tx_empty(&self) -> bool
In the FIFO mode, this is set to 1 when the TX FIFO and shift register are both empty.
Sourcepub const fn with_tx_empty(&self, field_value: bool) -> Self
pub const fn with_tx_empty(&self, field_value: bool) -> Self
In the FIFO mode, this is set to 1 when the TX FIFO and shift register are both empty.
Sourcepub fn set_tx_empty(&mut self, field_value: bool)
pub fn set_tx_empty(&mut self, field_value: bool)
In the FIFO mode, this is set to 1 when the TX FIFO and shift register are both empty.
Sourcepub const fn thr_empty(&self) -> bool
pub const fn thr_empty(&self) -> bool
In the FIFO mode, this is set to 1 when the TX FIFO is empty. There might still be a byte in the TX shift register.
Sourcepub const fn with_thr_empty(&self, field_value: bool) -> Self
pub const fn with_thr_empty(&self, field_value: bool) -> Self
In the FIFO mode, this is set to 1 when the TX FIFO is empty. There might still be a byte in the TX shift register.
Sourcepub fn set_thr_empty(&mut self, field_value: bool)
pub fn set_thr_empty(&mut self, field_value: bool)
In the FIFO mode, this is set to 1 when the TX FIFO is empty. There might still be a byte in the TX shift register.
Sourcepub const fn break_interrupt(&self) -> bool
pub const fn break_interrupt(&self) -> bool
Break interrupt.
Sourcepub const fn with_break_interrupt(&self, field_value: bool) -> Self
pub const fn with_break_interrupt(&self, field_value: bool) -> Self
Break interrupt.
Sourcepub fn set_break_interrupt(&mut self, field_value: bool)
pub fn set_break_interrupt(&mut self, field_value: bool)
Break interrupt.
Sourcepub const fn framing_error(&self) -> bool
pub const fn framing_error(&self) -> bool
Framing error.
Sourcepub const fn with_framing_error(&self, field_value: bool) -> Self
pub const fn with_framing_error(&self, field_value: bool) -> Self
Framing error.
Sourcepub fn set_framing_error(&mut self, field_value: bool)
pub fn set_framing_error(&mut self, field_value: bool)
Framing error.
Sourcepub const fn parity_error(&self) -> bool
pub const fn parity_error(&self) -> bool
Parity error.
Sourcepub const fn with_parity_error(&self, field_value: bool) -> Self
pub const fn with_parity_error(&self, field_value: bool) -> Self
Parity error.
Sourcepub fn set_parity_error(&mut self, field_value: bool)
pub fn set_parity_error(&mut self, field_value: bool)
Parity error.
Sourcepub const fn overrun_error(&self) -> bool
pub const fn overrun_error(&self) -> bool
Overrun error.
Sourcepub const fn with_overrun_error(&self, field_value: bool) -> Self
pub const fn with_overrun_error(&self, field_value: bool) -> Self
Overrun error.
Sourcepub fn set_overrun_error(&mut self, field_value: bool)
pub fn set_overrun_error(&mut self, field_value: bool)
Overrun error.
Sourcepub const fn data_ready(&self) -> bool
pub const fn data_ready(&self) -> bool
Data ready.
Sourcepub const fn with_data_ready(&self, field_value: bool) -> Self
pub const fn with_data_ready(&self, field_value: bool) -> Self
Data ready.
Sourcepub fn set_data_ready(&mut self, field_value: bool)
pub fn set_data_ready(&mut self, field_value: bool)
Data ready.